#
# spec file for package fluidsynth
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   3
Name:           fluidsynth
Version:        2.4.3
Release:        1.2
Summary:        A Real-Time Software Synthesizer That Uses Soundfont(tm)
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Sound/Midi
URL:            https://www.fluidsynth.orga/
Source0:        https://github.com/FluidSynth/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.conf
Source1000:     baselibs.conf
BuildRequires:  cmake >= 3.13.0
BuildRequires:  gcc-c++
BuildRequires:  ladspa-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libinstpatch-1.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sndfile)
Recommends:     fluid-soundfont-gm
%{?systemd_ordering}

%description
FluidSynth (formerly IIWU Synth) is a real-time software synthesizer
based on the SoundFont(tm) 2 specifications. It can read MIDI events
from the MIDI input device and render them to the audio device. It
can also play MIDI files.

%package devel
Summary:        Development package for the fluidsynth library
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libfluidsynth%{sover} = %{version}
Provides:       libfluidsynth-devel = %{version}

%description devel
This package contains the files needed to compile programs that use the
fluidsynth library.

%package -n libfluidsynth%{sover}
Summary:        Library for Fluidsynth
Group:          System/Libraries

%description -n libfluidsynth%{sover}
This package contains the shared library for Fluidsynth.

%prep
%autosetup -p1

%build
%cmake \
    -DFLUID_DAEMON_ENV_FILE=%{_fillupdir}/sysconfig.%{name} \
    -DDEFAULT_SOUNDFONT=/usr/share/sounds/sf2/FluidR3_GM.sf2
%cmake_build

%check
# depending on the distribution being built for, cmake
# may or may not create a 'build' subdirectory
%cmake
# cannot call ctest as the unit tests need to be compiled yet
%cmake_build check

%install
%cmake_install
install -Dpm0644 %{SOURCE1} %{buildroot}%{_fillupdir}/sysconfig.%{name}
install -Dpm0644 build/fluidsynth.service %{buildroot}%{_userunitdir}/%{name}.service
mkdir %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%pre
%systemd_user_pre %{name}.service

%post
%systemd_user_post %{name}.service

%preun
%systemd_user_preun %{name}.service

%postun
%systemd_user_postun %{name}.service

%post -n libfluidsynth%{sover} -p /sbin/ldconfig
%postun -n libfluidsynth%{sover} -p /sbin/ldconfig

%files
%license LICENSE
%doc AUTHORS ChangeLog.old README.md THANKS TODO
%{_bindir}/%{name}
%{_fillupdir}/sysconfig.%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_sbindir}/rc%{name}
%{_userunitdir}/%{name}.service

%files devel
%{_includedir}/%{name}
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%dir %{_libdir}/cmake/%{name}/
%{_libdir}/cmake/%{name}/*.cmake

%files -n libfluidsynth%{sover}
%{_libdir}/lib%{name}.so.%{sover}*

%changelog
* Sun Jan 26 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.3
  Bugfixes
  * It was discovered, that exclusive class note terminations were
    too slow.
  * Fix a regression introduced in 2.4.0 that allowed the
    amplitude of a voice playing in delay phase to rise infinitely.
  * MSGS drum-style note-cut has been converted to an opt-in
    setting synth.note-cut.
  * Support for SDL2 has been disabled by default.
  * Fix a regression introduced in 2.4.1 that could have caused
    infinite audio gain output for some MIDI files under certain
    configurations.
  * Silence a warning issued by Systemd v254+
- Update to version 2.4.2
  * Fix audible clicks when turning off voices while using a high
    filter resonance.
  * Restore discovery of libsndfile.
  * Fix a race condition when loading SF3 files containing
    multiple uncompressed samples.
- Update to version 2.4.1
  * Fix clicks and pops caused when changing parameters of the
    lowpass filter.
  * Minor adjustment to AWE32 NRPN behavior.
- Update to version 2.4.0
  New Features
  * Implement MSGS-style Drum Note Cut.
  * Add support for AWE32 NRPNs.
  * Add support for Polyphone's sample loop mode release.
  * Add support for SF2.04 absolute value modulators.
  Breaking Changes
  * LASH support has been removed.
  Musically Breaking changes
  * The default settings for reverb and chorus have been tuned to
    provide a more natural perception.
  * The behavior of the volume envelope's delay phase was
    previously incorrect.
  * The ModLfoToVolume generator was not able to increase the
    volume.
  * Fluidsynth's default device-id was changed, allowing it to
    process (most) SysEX events without further configuration.
  * Previously, some modulators were treated in a non-standard way
  Bug Fixes
  * The former linear interpolation of IIR filter coefficients
    could have caused audible clicks and cracks (#1345) - yet
    there is still a potential for clicks and cracks, see #1415
- Update to version 2.3.7
  * Fix SF3 decoder producing crackling sound for loud samples.
  * MIDI Format 2 is now rejected correctly since it was never
    supported.
  * Fix a regression introduced in 2.3.2 causing fluidsynth to
    fail discovering Oboe.
- Update to version 2.3.6
  * Fix discovery of gobject by CMake.
  * Fix a numerical instability that caused the chorus effect to
    stop working correctly when fluidsynth was compiled in single
    precision mode.
  * Fix timing issues in MIDI player related to incorrect handling
    of running status.
  * Fix ignoring LSB for RPN Pitch bend range events.
* Thu Apr  4 2024 Dirk Müller <dmueller@suse.com>
- update to 2.3.5:
  * Fix setting `synth.chorus.speed` to its minimum value being
    reported as out of range
  * Fix a regression causing libinstpatch and libsndfile not to
    be discovered on Windows
  * Fix Pipewire audio driver not cleanly being destroy
  * Fix selection logic for XG drum banks
  * Add cmake flag `FLUID_HOST_COMPILER` to allow overriding
    default host compiler required during compilation
  * LASH support has been deprecated
* Wed Jan 24 2024 Takashi Iwai <tiwai@suse.com>
- Drop the leftover directory for the old system-wide service
  (bsc#1219124)
* Tue Nov 21 2023 Dirk Müller <dmueller@suse.com>
- update to 2.3.4:
  * Fix a build failure when specifying `CMAKE_INSTALL_LIBDIR` as
    an absolute path (#1261, thanks to @OPNA2608)
  * Fix some MIDI files never finish playing (#1257, thanks to
    @joanbm)
  * Implement IPv6 to IPv4 fallback (#1208, thanks to @ivan-
    zaera)
  * Fix a build failure when using CMake's Xcode generator
    (#1266, thanks to @bradhowes)
  * Fix pipewire's Jack implementation not found by CMake (#1268,
    thanks to @pedrolcl)
  * Fix a regression causing the MIDI Player to terminate
    prematurely (#1272, thanks to @albedozero)
* Wed Jun 14 2023 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.3.3
  * Fix choppy sound when selecting pipewire output
  * Fix build issues on musl-based distros
  * Terminate MIDI player once internal synth-ticks overflow to prevent
    filling up the filesystem
  * Fix a bug that allowed playing notes outside of key and velocity ranges
* Wed Feb 15 2023 Florian <packaging@sp1rit.anonaddy.me>
- Fixed systemd service not starting by linking fluidsynth against
  libsystemd
* Thu Dec 29 2022 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.3.1
  * Prevent MIDI player from finishing prematurely
  * Fix a crash when enumerating rawmidi ALSA devices
  * Restore systemd sandboxing options and make it work with user units
  * Handle conflict with pipewire systemd daemon
- Fix bsc#1204236 by turning systemd service into user service
* Sat Sep 24 2022 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.3.0
  * CMake 3.13 is now required
  * for a full changelog, see https://github.com/FluidSynth/fluidsynth/wiki/ChangeLog#fluidsynth-230
- Remove hard-coded fluidsynth.service and use .service generated during build
* Tue Sep  6 2022 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.2.9:
  * Fix regression in WinMIDI driver introduced in 2.2.8
  * Tracks cannot be restarted in MIDI player after reaching EOT
  * Add a system-wide configuration file for Windows
  * Harden systemd service file
  * Dependency libs for precompiled Android binaries have been updated
- Remove harden_fluidsynth.service.patch as it has been addressed upstream
* Sun Jul 10 2022 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.2.8:
  * ALSA and WinMIDI drivers now pass system real-time messages on to user callback
  * Fix FPU division by zero in `fluid_player_set_tempo()`
  * Fix system-wide config file not loaded
  * Pluseaudio driver now honors `audio.periods` setting
* Mon Apr 25 2022 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.2.7
  * Fix file driver not working correctly on Windows
  * Add a function to create a sequencer event from a midi event
  * Precompiled x86 binaries are now x87-FPU compatible
  * Fix fluidsynth not responding to SIGINT and SIGTERM when using recent SDL2
* Thu Mar 24 2022 Dirk Müller <dmueller@suse.com>
- update to 2.2.6:
  * Undeprecation and minor revisal of the OSS driver
  * Minor improvements to CoreAudio and CoreMidi drivers
  * Fix sustained voices being held after ALL_CTRL_OFF
  * Fix clobbering of PORTAMENTO_CTRL after ALL_CRTL_OFF
  * Prevent Modulation Envelope from being stuck in decay phase, causing
    detuned voices and potentially other audible glitches for some soundfonts
  * Fix a compilation issue with recent glib
* Sun Feb  6 2022 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.2.5
  * Fix a build failure with CMake < 3.12
  * OSS and MidiShare drivers are now deprecated
  * Prevent samples accidentally having their loops disabled
  * Fix framework installation on MacOS
* Mon Nov 22 2021 tiwai@suse.de
- Update to 2.2.4:
  * Per-channel `ALL_SOUND_OFF` when seeking/stopping player
  * Fix windows related encoding problems
  * Rewind playlist when calling `fluid_player_play` after all loops are complete
  * Fix MinGW related static linking issues
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Drop ProtectClock hardening, can cause issues if other device acceess is needed
* Tue Sep 14 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_fluidsynth.service.patch
  Modified:
  * fluidsynth.service
* Sun Jul 11 2021 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.2.2
  * The MIDI router now handles out-of-range parameters in a smarter manner
  * Keep pedaling effective when the same note is played more than once
  * Select soundfont samples by frequency instead of midi note numbers
  * Fix the sequencer's event ordering for NoteOn vel=0 events
  * libfluidsynth's import library was broken for MinGW builds
  * fluidsynth.exe short option `-Q` not working
  * Precompiled Android binaries didn't work
  * Fix openMP detection for XCode 12.5
  * Make `audio.jack.autoconnect` connect all available ports
  * Prevent MIDI Player from continuously suppressing notes
  * `fluidsynth.pc` now includes private libraries for static linking
  * Fix typos in code and documentation
* Sat May  8 2021 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.2.1
  * Make ALSA the default driver on Linux
  * Coreaudio driver failed to initialize on MacOS 11
  * WaveOut driver failed to initialize
  * COM initialization in WASAPI driver is no longer performed in the
    caller's context
  * WASPI driver now supports reverb and chorus
  * Handle SysEx GM/GM2 mode on, GS reset, and XG reset
  * Old behaviour of `fluid_player_join` has been restored to prevent
    infinite loop in client code
  * The Soundfont loader code has been refactored, illegal generators
    will now be skipped more consequently
- Replace deprecated %%make_jobs macro with %%cmake_build
* Wed Apr  7 2021 tiwai@suse.de
- Update baselibs.conf for the soversion 3
* Fri Apr  2 2021 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.2.0
  * for a full changelog, see https://github.com/FluidSynth/fluidsynth/wiki/ChangeLog#fluidsynth-220
  * for API/ABI breaking changes, see https://www.fluidsynth.org/api/RecentChanges.html#NewIn2_2_0
- bump soversion to 3
- require a C++ compiler
- add RPM groups
- demote fluid-soundfont-gm to "Recommends" (previously, the user was forced
  to install this package, even if he used a custom soundfont in the .conf file)
* Tue Mar 16 2021 Dirk Müller <dmueller@suse.com>
- update to 2.1.8:
  * Rapidly changing channel panning could have caused audible artifacts (#768).
  * Fix a use-after-free when loading malformed soundfonts (#808). Affects all
    versions back to at least 1.1.2.
  * The number of allowed LADSPA effect units has been increased.
* Fri Jan 29 2021 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to version 2.1.7
  * a regression introduced in `2.1.0` prevented chorus from being
    audible when `fluid_synth_process()` was used
  * a regression introduced in `2.0.6` prevented the MIDI player from
    restarting playback after all files have been played
  * fix a double-free violation introduced in `2.0.0` after executing
    the `info` shell command
* Sat Jan  9 2021 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to version 2.1.6
  * SoundFonts may never be unloaded correctly, if
  * polyphony is ever exceeded, or
  * voices are still playing while their SoundFont is being unloaded.
  * fix a heap-based use-after-free
* Mon Oct 19 2020 Илья Индиго <ilya@ilya.pp.ua>
- Refresh spec-file via spec-cleaner and manual optimizations.
- Add Requires:fluid-soundfont-gm.
- Add user fluidsynth and group audio.
- Add files: fluidsynth.conf and fluidsynth.service.
* Sun Sep 20 2020 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to version 2.1.5
  * loading DLS may have failed in certain setup environments
  * fix a build failure with GCC 4.8
* Mon Jul 13 2020 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to version 2.1.4
  * fix an uninitialized memory access possibly triggering an FPE
    trap
  * fix several regressions introduced in 2.1.3:
  * `fluid_synth_start()` failed for certain presets
  * fix a NULL dereference in jack driver
  * fix a stack-based overflow when creating the synth
* Tue May 26 2020 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to version 2.1.3
  * fix a cross-compilation failure from Win32 to WinARM
  * fix issues while `fluid_player` is seeking
  * fix a NULL pointer dereference if `synth.dynamic-sample-loading`
    is enabled
  * fix a NULL pointer dereference in `delete_rvoice_mixer_threads()`
  * fix a NULL pointer dereference in the soundfont loader
  * fix dsound driver playing garbage when terminating fluidsynth
  * avoid memory leaks when using libinstpatch
* Mon Apr 13 2020 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to version 2.1.2
  * fluidsynth now exits with error when user-provided command-line
    arguments are out-of-range
  * add verbose error logging to opensles and oboe drivers
  * fix a memory leak in oboe driver
  * fix a NULL dereference in the fluidsynth commandline program
* Thu Feb 20 2020 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to version 2.1.1
  * a regression introduced in 2.1.0 caused the jack audio driver
    to not correct a sample-rate mismatch
  * pkg-config is now being to used to find readline
  * fix various typos in the documentation
  * fix a memory leak in the file renderer
  * fix leaking memory when sequencer clients were not explicitly
    unregistered
  * fix a heap-based use-after-free in jack driver
  * fix the linker possibly not finding libinstpatch
* Fri Dec 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.1.0
  New features:
  * new, less "ringing" reverb engine (#380, thanks to @jjceresa)
  * new, stereophonic chorus engine (#548, thanks to @jjceresa)
  * support for Downloadable Sounds (DLS) files was added (#320,
    requires libinstpatch)
  * improved integrity checking of SoundFont modulators (#467,
    thanks to @jjceresa)
  * rendering to stdout is now possible (#553, thanks to @mawe42)
  * the following Audio Drivers have been added:
    + Oboe (#464, tested on Android, thanks to @atsushieno)
    + OpenSLES (#464, tested on Android, thanks to @atsushieno)
    + SDL2 (#478, thanks to @carlo-bramini)
    + WaveOut (#466, tested on Win98, WinNT4.0, WinXP, thanks to
    @carlo-bramini)
  * various performance improvements (#543, #545, #547, #569,
    [#573])
  Bug fixes:
  * generator modEnvAttack now has a convex shape according to
    SoundFont spec (#153)
  * the default MIDI Pitch Wheel to Initial Pitch modulator now
    uses Fine Tune as destination generator, allowing it to be
    overridden by the soundfont designer (#154, thanks to
    @jjceresa)
  version 2.0.9
  * an implicitly declared function caused a pointer to int
    truncation in CoreAudio driver (#591)
  * fix a stack-based overflow in CoreAudio driver (#594, thanks
    to @fkmclane)
- Enable sdl2 and libinstpatch
- Spec cleanup
* Mon Oct 28 2019 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.0.8
  * fix incorrect behavior of `fluid_sample_set_sound_data()`
  * fix voices being mixed incorrectly, causing audible crackle esp.
    at sample-rates >48kHz
  * make sure that defining `NDEBUG` disables assertions
* Thu Oct 10 2019 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.0.7
  * fix broken audio output when reverb was active after synth creation
  * fix debug console messages not being visible for debug builds on
    Windows
* Mon Aug 19 2019 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.0.6
  * fix an uninitialized memory access, which could have led to NULL
    dereference or heap corruption in an out-of-memory situation
  * fix a use-after-free when calling `fluid_player_stop()`
  * fix the MIDI player not outputting any sound after stopping and
    restarting the playback
* Fri Apr 19 2019 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.0.5
  * the MIDI player erroneously assumed a default tempo of 125 BPM
    rather than 120 BPM
  * improve integration of systemd
  * fix a buffering bug in fluid_synth_process()
  * fix a major memory leak when unloading SF3 files
  * fix multiple NULL dereferences and memory leaks in jack driver
  * fix a memory leak when creating threads
* Sat Feb 23 2019 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.0.4:
  * introduce verbose error reporting for `fluid_settings_*` functions
  * avoid undefined behavior when `fopen()` directories
  * improve compatibility with FreeBSD and DragonFlyBSD (#508, thanks to @t6)
  * fix build when cross compiling (#501)
  * fix build on MacOSX 10.4 (#513)
  * fix build when compiling with MinGW
  * enable network support on Mac by default (#513)
* Wed Jan  2 2019 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.0.3:
  * fix handle leak in winmidi driver
  * fix build failures when cross compiling
  * fix a bug when calculating the lower boundary of attenuation
  * fix a double free in `fluid_sample_set_sound_data()`
  * silence a warning when loading soundfonts from memory
  * minor performance improvements
* Sun Nov 18 2018 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 2.0.2:
  * fix building fluidsynth without any audio drivers
  * fix a possibly misaligned memory access in the soundfont loader
  * fix a memory leak in the pulse audio driver
  * fix a NULL deref in the coreaudio driver
  * use cmake to query for DSound and WinMidi support
  * remove an unintended MFC dependency header
  * include Windows DLL version info for MinGW builds
  * implement midi.autoconnect for jack
  * add a cmake option to disable multi-threading
* Sun Oct  7 2018 tom.mbrt@googlemail.com
- Update to 2.0.1:
  * implement auto-conntect for CoreMidi
  * fix a build issue with cmake < 3.3
  * fix a crash when creating multiple jack drivers
  * various fixes to dsound driver
  * fix multiple potential NULL dereferences
  * fix two memory leaks in the soundfont loader
  * correct upper threshold of synth.chorus.depth
- Remove fluidsynth-last_client-reuse-fix.patch
* Sat Sep 29 2018 Luigi Baldoni <aloisio@gmx.com>
- Backported fluidsynth-last_client-reuse-fix.patch from master
  (qsynth crashes without it)
* Fri Sep 14 2018 tom.mbrt@googlemail.com
- Update to 2.0.0:
  * for a full changelog, see https://github.com/FluidSynth/fluidsynth/wiki/ChangeLog#fluidsynth-200
  * for API/ABI breaking changes, see http://www.fluidsynth.org/api/index.html#NewIn2_0_0
- bump soversion to 2
- require cmake >= 3.1.0
- execute unit tests (make check)
- remove cmake option 'enable-ladspa' as it's now enabled by default
- add conditionals to spec file to allow builds for other RPM-based distributions
* Sun May  6 2018 tom.mbrt@googlemail.com
- Update to 1.1.11:
  * fix pkgconfig file for absolute paths
  * add a cmake option for OSS support
  * fix broken enable-midishare cmake option
  * fix double free in fluid_midi_router
  * prevent malicious soundfonts from causing buffer overflows
  * avoid SF3 files to be loaded incorrectly
  * fix an endless loop in fast file renderer
- remove 0001-Fix-pkgconfig-file-for-absolute-paths-347.patch
* Tue Mar  6 2018 tom.mbrt@googlemail.com
- Add 0001-Fix-pkgconfig-file-for-absolute-paths-347.patch
  to fix pkgconfig file generation when absolute lib and include
  paths are used (boo#1084081)
* Fri Mar  2 2018 tom.mbrt@googlemail.com
- Avoid using indirection macros
- Do not hard-code /usr/sbin
* Sun Feb 25 2018 tom.mbrt@googlemail.com
- Update to 1.1.10:
  * avoid a buffer overrun when loading malformed soundfonts
  * fix synth.default-soundfont returning incomplete path
  * improve reliability of fluid_is_soundfont()
  * include windows version info in libfluidsynth.dll
  * enable jack midi driver to support more than 16 midi channels
  * minor cmake adjustments for MSVC builds to enable building fluidsynth as vcpkg package
  * fix build issues against statically built fluidsynth library on all OSs
  * enable fluidsynth to be set up as systemd user service
  * cmake: prevent double usage of LIB_SUFFIX and LIB_INSTALL_DIR
- Install systemd service files
* Thu Feb 15 2018 tchvatal@suse.com
- Switch to cmake macros
- Use %%license to install license
- Disable optional lash support as we try to remove lash
- Format with spec-cleaner
* Thu Jan  4 2018 tom.mbrt@googlemail.com
- Update to version 1.1.9:
  * fix building the portaudio driver on Windows
  * fix build if no MIDI drivers are available
  * fix return value of fluid_file_set_encoding_quality()
  * fix use-after-free in fluid_timer
  * fix memory leak in pulseaudio driver
  * fix memory leak in rvoice_mixer
  * fix dumptuning shell command displaying uninitialized values
  * fix a resource leak in source shell command
  * harmonize fluidsynth's output library naming with autotools on Windows
  * dont set LIB_SUFFIX when building with MinGW
  * avoid a possible deadlock when initializing fluidsynths DLL on windows
  * avoid a buffer overrun when mixing effects channels in fluid_synth_nwrite_float()
  * correctly clean up fluid_server on Windows
  * implement handling of FLUID_SEQ_ALLSOUNDSOFF events in fluid_seq_fluidsynth_callback()
  * support for registering audio drivers based on actual needs
* Fri Oct 13 2017 tom.mbrt@googlemail.com
- Update to version 1.1.8:
  * fix build against glib < 2.30
  * fix dsound audio driver on windows
  * fix a bug around `synth.audio-groups` setting, which caused improper multi-channel rendering
  * cmake 3.0.2 is now required
  * compilation with clang is now possible
  * build fixes on OS/2
- Use pkgconfig for resolving build requirements
- Minor description update
* Wed Sep  6 2017 tom.mbrt@googlemail.com
- Update to version 1.1.7:
  * consistently relicense libfluidsynth under LGPL-2.1+
  * fluid_synth_set_channel_type() was not exported properly
  * fix calculations for modulators
  * fix SysEx parsing issues
  * fix mangling with illegal sample loops, causing audible glitches
  * fix inverse logic of audio.jack.multi option
  * fix channel fine tune RPN to use correct range
  * fix timing problems when changing the sequencers scale from a callback event
  * workaround incorrectly rendered audio when requesting more than 64 frames from fluid_synth_write_*()
  * adjust ALSA MIDI port type
  * avoid voice_count becoming negative
  * avoid notes with a fixed key generator playing forever
  * avoid TCP/IP connections from closing in an undefined manner
  * a lot of memory leaks, NULL dereferences and SegFaults
  * add support of vorbis-compressed sf3 sound fonts
  * add sostenuto pedal to the synth
  * add vbr quality when encoding with libsndfile
  * re-implement routing reverb and chorus to distinct buffers in fluid_synth_nwrite_float()
  * add IPv6 support to socket API
- remove the following patches as they got fixed upstream:
  * fluidsynth-fix-build-lash.diff
  * jackmulti.diff
  * reverb_mixer.diff
* Sun Nov 22 2015 idonmez@suse.com
- Add baselibs.conf as a source file
* Sun Nov 22 2015 tom.mbrt@googlemail.com
- Added jackmulti.diff to fix inverse logic of audio.jack.multi option
- Added reverb_mixer.diff to workaround reverb issue,
  see: http://sourceforge.net/p/fluidsynth/tickets/137/
* Mon Sep 24 2012 schwab@linux-m68k.org
- Use %%{optflags}
* Fri Sep 21 2012 zaitor@opensuse.org
- Update to version 1.1.6:
  + Handle MIDI End of track events.
  + Prevent broken rendering after an voice overflow.
  + Enable long arguments where available.
  + Windows: Install fluidsynth.pc (pkg-config spec).
  + Mac OS X Lion: Fix build failure.
  + Linux: Prevent libdbus crash.
* Mon Jun  4 2012 toddrme2178@gmail.com
- Added 32-bit compatibility library (needed by
  gstreamer-0_10-plugins-buzztard-32bit )
* Tue Jan 10 2012 reddwarf@opensuse.org
- Updated to 1.1.5
  + Autotools build resulted in the wrong version number for
    libfluidsynth.so
  + One symbol was dropped from libfluidsynth.so - this symbol was
    not part of the public API though
  + JACK: Using jack_free instead of free when needed
  + Update Free Software Foundation address
- Run spec-cleaner
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Mon Aug  8 2011 tiwai@suse.de
- Updated to version 1.1.4:
  Improvements to the API for playing MIDI files, several bug fixes
  in the engine itself; for details, see:
    http://sourceforge.net/apps/trac/fluidsynth/wiki/ChangeLog1_1_4
- Use cmake for build
- Re-add a symbol dropped from 1.1.3
- Clean up spec file
* Fri Dec 31 2010 lnussel@suse.de
- provide libfluidsynth-devel for compatibility with packman
* Mon Oct 11 2010 oliver.bengs@opensuse.org
- Updated to version 1.1.3:
  + Compilation with LADSPA enabled was broken in 1.1.2
  + Multichannel output broken when double precision was used
  + Doxygen settings
  + Fix build problem with scummvm
  + Optimize by not starting unused threads with multicore rendering
  + Race condition in alsa_seq / alsa_raw drivers caused them not to quit
* Thu Sep  2 2010 oliver.bengs@opensuse.org
- Updated to version 1.1.2:
  see details in
  http://sourceforge.net/apps/trac/fluidsynth/wiki/ChangeLog1_1_2
- disabled LADSPA, because it is broken in this release
- enabled dbus and libsndfile
* Fri Apr  2 2010 davejplater@gmail.com
- Updated to version 1.1.1
- FluidSynth 1.1.1 - "Clarity", see Changes page for details.
  http://fluidsynth.resonance.org/trac/wiki/ChangeLog1_1_1
  This is a rather major bug fix release to version 1.1.0.
  FluidSynth 1.1.0 - "A More Solid Fluid", see Changes page for details.
  http://fluidsynth.resonance.org/trac/wiki/ChangeLog1_1_0
  This is the result of a 6 month development cycle and is the most
  significant release since 1.0.0!
* Mon Jul 27 2009 tiwai@suse.de
- updated to version 1.0.9:
  see details in
    http://fluidsynth.resonance.org/trac/wiki/ChangeLog1_0_9
- add support of pulseaudio and LASH
* Mon Apr 14 2008 schwab@suse.de
- Avoid libtool namespace clash.
* Tue Nov 20 2007 tiwai@suse.de
- updated to version 1.0.8:
  * Improved synthesis interpolation
  * Dithering on 16 bit converted output
  * Updated fluidmax plugin with polyphony parameter.
  * Improved ALSA audio and sequencer drivers.
  * Fixed some Floating Point Exceptions which were causing
    excessive CPU usage
  * Some fixes to Chorus and Reverb parameters
  * Looping/tuning problem when loop end close to end of sample
  * FluidSynth crashes with QSynth and audio meters turned on
  * ALSA sequencer driver no longer prints out false errors
  * Many memory leaks plugged
  * Warning message printed if a non option is not a valid
    SoundFont or MIDI file
* Tue Apr 17 2007 tiwai@suse.de
- follow library packaging policy
  * split shared library to libfluidsynth1 sub package
  * remove static library
- fix buildrequires ladspa-devel
* Mon May 15 2006 tiwai@suse.de
- updated to version 1.0.7a.
  * cleanup of LADCCA support
  * fix warnings with JACK backend
  * fix sequencer buffer overrun bug
  * new filter routine
  * crash bugfix
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 12 2005 tiwai@suse.de
- fix the crash with 64bit architectures (#137998)
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Tue Jun 14 2005 tiwai@suse.de
- updated to version 1.0.6.
- split fluidsynth-dssi to an individual package (built from
  own tarball).
* Fri Apr  8 2005 tiwai@suse.de
- fix for gcc-4.0.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 1.0.5.
* Tue Aug 17 2004 tiwai@suse.de
- fixed the build of fluidsynth-dssi plugin.
* Tue Aug 17 2004 tiwai@suse.de
- Added the DSSI plugin support.
  A new subpackage fluidsynth-dssi is created.
* Mon Apr 26 2004 ro@suse.de
- add -fno-strict-aliasing
* Tue Jan 13 2004 tiwai@suse.de
- added non-root build.
- added %%run_ldconfig.
- fixed %%defattr.
* Tue Nov 18 2003 tiwai@suse.de
- updated to version 1.0.3.
* Thu Aug 28 2003 tiwai@suse.de
- fixed bugs; retrieved from 1.0.3.
* Thu Jul  3 2003 tiwai@suse.de
- updated to version 1.0.2.
* Fri Jun  6 2003 tiwai@suse.de
- updated to version 1.0.1.
* Thu Mar 27 2003 tiwai@suse.de
- initial version 1.0.0.  iiwusynth is obsoleted.
